#' @docType data
#' @name example_matrix
#'
#' @title Example matrix data
#' @description The matrix used for reconstruct gene regulatory network.
#'
NULL

#' @docType data
#' @name example_ground_truth
#'
#' @title Example ground truth data
#' @description The data used for calculate the evaluating indicator.
#'
NULL

#' @docType data
#' @name example_meta_data
#'
#' @title Example meta data
#' @description The data contains cells and pseudotime information.
#'
NULL
